@@ -3,7 +3,7 @@ import sys
 import abc
 import types
 
-from yasv.compat import with_metaclass, string_types
+from six import with_metaclass, string_types
 
 
 __all__ = [
@@ -38,6 +38,7 @@ class Validator(with_metaclass(abc.ABCMeta)):
         self._template = None
         self._args = args
         self._kwargs = kwargs
+
         for arg in args:
             if isinstance(arg, types.FunctionType):
                 setattr(self, arg.__name__, types.MethodType(arg, self))
@@ -45,6 +46,11 @@ class Validator(with_metaclass(abc.ABCMeta)):
             elif isinstance(arg, string_types):
                 self._template = arg
 
+        if self._template:
+            self.template = self._template
+        else:
+            self.template = self.default_template
+
     def validate(self, value, field):
         self.value = value
         if not (self.specified_type() and self.on_missing() and self.on_blank()
@@ -74,8 +80,7 @@ class Validator(with_metaclass(abc.ABCMeta)):
         """"""
 
     def process_template(self, field):
-        template = self._template if self._template else self.default_template
-        return template.format(*self.template_params())
+        return self.template.format(*self.template_params())
 
 
 class Required(Validator):
@@ -169,7 +174,7 @@ class RegexpValidator(String, with_metaclass(abc.ABCMeta)):
         """"""
 
     def on_value(self):
-        return True if self.regex.match(self.value) else False
+        return True if not self.value or self.regex.match(self.value) else False
 
     def __deepcopy__(self, memo):
         return self.__class__(*self._args, **self._kwargs)
